Code coverage report for js/components/Link.tsx

# All files / js/components Link.tsx

33.33% Statements 2/6
0% Branches 0/2
0% Functions 0/1
33.33% Lines 2/6

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    151x
    1x

     import React, { ReactNode } from "react";
    import { NavLink } from "react-router-dom";

    export default function LektorLink(props: { to: string; children: ReactNode }) {
      let path = props.to;
      if (path.substr(0, 1) !== "/") {
        path = `${$LEKTOR_CONFIG.admin_root}/${path}`;
      }
      return (
        <NavLink to={path} activeClassName="active">
          {props.children}
        </NavLink>
      );
    }